@@ -1,48 +1,23 @@
-#ifdef __cplusplus
-/* Needed on some windows machines---since MS plays funny
-   games with the header files under C++ */
-#include <math.h>
-#include <stdlib.h>
-extern "C" {
-#endif
-#include "EXTERN.h"
-#include "perl.h"
-#include "XSUB.h"
-
-/* Get rid of free and malloc defined by perl */
-#undef free
-#undef malloc
-
-#include <string.h>
-#ifdef __cplusplus
-}
-#endif
-
-#if !defined(PERL_REVISION) || ((PERL_REVISION >= 5) && ((PERL_VERSION < 5) || ((PERL_VERSION == 5) && (PERL_SUBVERSION < 50))))
-#ifndef PL_sv_yes
-#define PL_sv_yes PL_sv_yes
-#endif
-#ifndef PL_sv_undef
-#define PL_sv_undef PL_sv_undef
-#endif
-#ifndef PL_na
-#define PL_na PL_na
-#endif
-#endif
+#ifndef __PERLCONTENTCALLBACKHANDLER
+#define __PERLCONTENTCALLBACKHANDLER
 
+#include "PerlCallbackHandler.hpp"
 #include "xercesc/sax2/ContentHandler.hpp"
 #include "xercesc/util/XMLString.hpp"
-class PerlContentCallbackHandler : public ContentHandler {
+class PerlContentCallbackHandler : public ContentHandler
+				 , public PerlCallbackHandler 
+{
 
-private:
-    SV *callbackObj;
+protected:
+//    SV *callbackObj;
 
 public:
 
-    PerlContentCallbackHandler();
-    ~PerlContentCallbackHandler();
+    PerlContentCallbackHandler() {};
+    PerlContentCallbackHandler(SV *obj) : PerlCallbackHandler(obj){};
+    ~PerlContentCallbackHandler() {};
 
-    void set_callback_obj(SV*);
+    SV* set_callback_obj(SV*);
 
 	// The ContentHandler interface
     void startElement(const   XMLCh* const    uri,
@@ -68,3 +43,4 @@ public:
     void skippedEntity (const XMLCh* const name);
 };
 
+#endif /* __PERLCONTENTCALLBACKHANDLER */
